==> nuiton-utils-maven-report-plugin-2.6.12-sources.jar: org/nuiton/util/config/AggregateApplicationConfigReport.java <==
package org.nuiton.util.config;

/*
 * #%L
 * Nuiton Utils :: Maven Report Plugin
 * $Id: AggregateApplicationConfigReport.java 2521 2013-03-03 15:20:18Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.6.12/nuiton-utils-maven-report-plugin/src/main/java/org/nuiton/util/config/AggregateApplicationConfigReport.java $
 * %%
 * Copyright (C) 2012 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.apache.maven.artifact.DependencyResolutionRequiredException;
import org.apache.maven.plugins.annotations.Execute;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.plugins.annotations.ResolutionScope;
import org.apache.maven.project.MavenProject;
import org.apache.maven.reporting.MavenReportException;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Generates a report for declarated application config via the
 * {@link ApplicationConfigProvider} mecanism on a aggregate mojo.
 * <p/>
 * For each configuration, you can find all his options and actions.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.10
 */
@Mojo(name = "aggregate-config-report", aggregator = true,
      requiresProject = true, requiresReports = true,
      requiresDependencyResolution = ResolutionScope.RUNTIME)
@Execute(phase = LifecyclePhase.COMPILE)
public class AggregateApplicationConfigReport extends AbstractApplicationConfigReport {

    /**
     * The projects in the reactor.
     *
     * @since 2.6.10
     */
    @Parameter(property = "reactorProjects", readonly = true, required = true)
    protected List<?> reactorProjects;

    @Override
    protected ClassLoader createClassLoader() throws MavenReportException {
        Set<String> paths = new HashSet<String>();

        for (Object o : reactorProjects) {
            MavenProject p = (MavenProject) o;
            try {
                List runtimeClasspathElements = p.getRuntimeClasspathElements();
                paths.addAll(runtimeClasspathElements);
            } catch (DependencyResolutionRequiredException e) {
                throw new MavenReportException("Could not obtain dependencies for project " + p);
            }
        }
        return createClassLoader(paths);
    }
}

==> nuiton-utils-maven-report-plugin-2.7-sources.jar: org/nuiton/util/config/AggregateApplicationConfigReport.java <==
package org.nuiton.util.config;

/*
 * #%L
 * Nuiton Utils :: Maven Report Plugin
 * $Id: AggregateApplicationConfigReport.java 2521 2013-03-03 15:20:18Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.7/nuiton-utils-maven-report-plugin/src/main/java/org/nuiton/util/config/AggregateApplicationConfigReport.java $
 * %%
 * Copyright (C) 2012 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

import org.apache.maven.artifact.DependencyResolutionRequiredException;
import org.apache.maven.plugins.annotations.Execute;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.plugins.annotations.ResolutionScope;
import org.apache.maven.project.MavenProject;
import org.apache.maven.reporting.MavenReportException;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Generates a report for declarated application config via the
 * {@link ApplicationConfigProvider} mecanism on a aggregate mojo.
 * <p/>
 * For each configuration, you can find all his options and actions.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.6.10
 */
@Mojo(name = "aggregate-config-report", aggregator = true,
      requiresProject = true, requiresReports = true,
      requiresDependencyResolution = ResolutionScope.RUNTIME)
@Execute(phase = LifecyclePhase.COMPILE)
public class AggregateApplicationConfigReport extends AbstractApplicationConfigReport {

    /**
     * The projects in the reactor.
     *
     * @since 2.6.10
     */
    @Parameter(property = "reactorProjects", readonly = true, required = true)
    protected List<?> reactorProjects;

    @Override
    protected ClassLoader createClassLoader() throws MavenReportException {
        Set<String> paths = new HashSet<String>();

        for (Object o : reactorProjects) {
            MavenProject p = (MavenProject) o;
            try {
                List runtimeClasspathElements = p.getRuntimeClasspathElements();
                paths.addAll(runtimeClasspathElements);
            } catch (DependencyResolutionRequiredException e) {
                throw new MavenReportException("Could not obtain dependencies for project " + p);
            }
        }
        return createClassLoader(paths);
    }
}
